@@ -9,11 +9,28 @@ use syn::parse::{Parse, ParseStream};
 use syn::parse_macro_input;
 use syn::punctuated::Punctuated;
 
+/// Convert RISC-V Vector Extension to `.byte 0x00, 0x11, 0xaa, 0xbb` format asm instructions.
+///
+/// ## Example:
+/// Compile will fail due to target not supported on develop/CI machine.
+/// ```compile_fail
+/// let lo: i64;
+/// unsafe {
+///     rvv_asm::rvv_asm!(
+///         "vsetvl x5, s3, t6",
+///         "1: vle256.v v3, (a0), vm",
+///         "2:",
+///         "li {lo}, 4",
+///         lo = out(reg) lo,
+///     );
+/// }
+/// ```
 #[proc_macro]
 pub fn rvv_asm(item: TokenStream) -> TokenStream {
     transform(item, false)
 }
 
+/// Convert **reserved only** RISC-V Vector Extension to `.byte 0x00, 0x11, 0xaa, 0xbb` format asm instructions.
 #[proc_macro]
 pub fn rvv_asm_reserved_only(item: TokenStream) -> TokenStream {
     transform(item, true)
@@ -25,9 +42,12 @@ fn transform(item: TokenStream, reserved_only: bool) -> TokenStream {
     let mut args: Option<TokenStream2> = None;
     for item in items.inner {
         match item {
-            Item::LitStr(inst) => {
-                insts.extend(inst.value().split('\n').map(|s| s.to_string()))
-            },
+            Item::LitStr(content) => {
+                for part in content.value().split('\n') {
+                    // For support inline label
+                    insts.extend(part.split_inclusive(':').map(|s| s.to_string()));
+                }
+            }
             Item::Args(tokens) => {
                 if args.is_some() {
                     panic!("Args between string literal is not allowed");
@@ -109,7 +129,7 @@ mod tests {
     #[test]
     fn test_vle_n_v() {
         assert_eq!(
-            rvv_asm_inner(&["vle128.v v3, (a0), vm"], None, false)
+            rvv_asm_inner(&["vle128.v v3, (a0), v0.t"], None, false)
                 .unwrap()
                 .to_string(),
             quote!(asm!(".byte 0x87, 0x01, 0x05, 0x10",);).to_string()
@@ -165,8 +185,8 @@ mod tests {
         let expected_output = quote! {
             asm!(
                 ".byte 0xd7, 0xf2, 0xf9, 0x81",
-                "li {a}, 3",
                 "1: ",
+                "li {a}, 3",
                 "apple_pie:",
                 "li {hi}, 4",
                 a = in (reg) a ,
@@ -177,8 +197,8 @@ mod tests {
             rvv_asm_inner(
                 &[
                     "vsetvl x5, s3, t6",
-                    "li {a}, 3",
                     "1: ",
+                    "li {a}, 3",
                     "apple_pie:",
                     "li {hi}, 4",
                 ],
@@ -188,8 +208,8 @@ mod tests {
                 }),
                 false,
             )
-                .unwrap()
-                .to_string(),
+            .unwrap()
+            .to_string(),
             expected_output.to_string()
         );
     }
